﻿using System;
using System.Collections.ObjectModel;
using System.Collections.Specialized;
using System.ComponentModel;
using System.Linq;
using System.Windows.Input;
using Microsoft.Practices.Prism.Commands;
using Microsoft.Practices.Prism.Mvvm;

namespace WpfApplication1
{
    public class MainWindowViewModel : BindableBase
    {
        public ICommand SaveCommand { get; private set; }

        private ObservableCollection<Car> _carCollection = new ObservableCollection<Car>();
        public ObservableCollection<Car> CarCollection
        {
            get { return _carCollection; }
            set { SetProperty(ref _carCollection, value); }
        }

        private bool _isEnabled = false;
        public bool IsEnabled
        {
            get { return _isEnabled; }
            set { SetProperty(ref _isEnabled, value); }
        }

        private object _activeRecord;
        public object ActiveRecord
        {
            get { return _activeRecord; }
            set { SetProperty(ref _activeRecord, value); }
        }

        public MainWindowViewModel()
        {
            SaveCommand = new DelegateCommand(OnSave);

            CarCollection.CollectionChanged += CarCollection_CollectionChanged;

            CarCollection.Add(Car.GetCar("BMW"));
            //CarCollection.Add(Car.GetCar("Ford"));
            //CarCollection.Add(Car.GetCar("Toyota"));
            //CarCollection.Add(Car.GetCar("Nissan"));
        }

        private void OnSave()
        {
            CarCollection.Clear();
            CarCollection.Add(Car.GetCar("BMW1"));
            //If the CarCollection has more than one Item, all good. 
            //If less than one Item, the cell focus does not behave properly
            //CarCollection.Add(Car.GetCar("Ford1"));
            //CarCollection.Add(Car.GetCar("Toyota1"));
            //CarCollection.Add(Car.GetCar("Nissan1"));

            IsEnabled = false;

            ActiveRecord = CarCollection[0];
        }

        private void CarCollection_CollectionChanged(object sender, NotifyCollectionChangedEventArgs e)
        {
            if (e.OldItems != null)
            {
                foreach (INotifyPropertyChanged oldItem in e.OldItems)
                {
                    oldItem.PropertyChanged -= CollectioItemChanged;
                }
            }

            if (e.NewItems != null)
            {
                foreach (INotifyPropertyChanged newItem in e.NewItems)
                {
                    newItem.PropertyChanged += CollectioItemChanged;
                }
            }
        }

        private void CollectioItemChanged(object sender, PropertyChangedEventArgs e)
        {
            IsEnabled = true;
        }
    }

}

